@@ -3,9 +3,9 @@ use std::fmt::Formatter;
 use path_slash::PathExt;
 use salsa::Durability;
 
+use crate::Db;
 use crate::file_revision::FileRevision;
 use crate::system::{SystemPath, SystemPathBuf};
-use crate::Db;
 
 /// A root path for files tracked by the database.
 ///
@@ -23,7 +23,7 @@ pub struct FileRoot {
     pub path: SystemPathBuf,
 
     /// The kind of the root at the time of its creation.
-    kind_at_time_of_creation: FileRootKind,
+    pub kind_at_time_of_creation: FileRootKind,
 
     /// A revision that changes when the contents of the source root change.
     ///
